@@ -6,22 +6,22 @@ from .exceptions import (LanguageInvalidException, NoSuchFileException,
                          OEMInvalidException, PSMInvalidException)
 
 
-async def psm_is_valid(psm: int) -> None:
+def psm_is_valid(psm: int) -> None:
     if psm not in PAGE_SEGMENTATION_MODES.keys():
         raise PSMInvalidException
 
 
-async def oem_is_valid(oem: int) -> None:
+def oem_is_valid(oem: int) -> None:
     if oem not in OCR_ENGINE_MODES.keys():
         raise OEMInvalidException
 
 
-async def file_exists(file_path: str) -> None:
+def file_exists(file_path: str) -> None:
     if not Path(file_path).exists():
         raise NoSuchFileException(f"No such file: '{file_path}'")
 
 
-async def language_is_valid(language: str) -> None:
+def language_is_valid(language: str) -> None:
     for lang in language.split("+"):
         if lang not in TESSERACT_LANGUAGES:
             raise LanguageInvalidException(
