@@ -21,6 +21,17 @@ async def test_image_to_string_with_bytes_image(image):
     assert len(text) >= 90
 
 
+@pytest.mark.asyncio
+@pytest.mark.parametrize("image", ["tests/samples/file-sample_150kB.png"])
+async def test_image_to_string_with_bytes_image_args(image):
+    text = await aiopytesseract.image_to_string(
+        Path(image).read_bytes(),
+        tessdata_dir="tests/samples/tessdata_fast",
+    )
+    assert isinstance(text, str)
+    assert len(text) >= 90
+
+
 @pytest.mark.asyncio
 async def test_image_to_string_with_invalid():
     with pytest.raises(RuntimeError):
